<?php
App::uses('Component', 'Controller');
App::uses('Validation', 'Utility');

class CustomFieldsComponent extends Component
{
    private $__controller = null;

    /**
     * Sets a reference to the calling controller from within the component.
     *
     * @see Component::initialize()
     */
    public function initialize(Controller $controller) {

        parent::initialize($controller);

        $this->__controller = $controller;
    }

    /**
     * run the form injection
     * For custom fields this add type / validation arrays to the template for fields
     *
     * @param   array       Data from $this->request->data
     * @param   object      Model Object for the primary model we are dealing with
     * @param   int|null    The ID if on edit or null of add
     */
    public function injectAdminForm($data, $Model, $id)
    {
        $validationReflection = new ReflectionClass(new Validation);
        $validationMethods = $validationReflection->getMethods(ReflectionMethod::IS_PUBLIC);
        $rules = array();
        foreach ($validationMethods as $item) {

            $paramCount = $item->getNumberOfParameters();

            /**
             * decreament as all parameters pass the value automatically,
             * this will give us the number of params, the dev has to enter
             */
            $paramCount--;
            if ($paramCount === 1) {
                $paramCount .= ' Param';
            } else {
                $paramCount .= ' Params';
            }

            $rules[$item->name] = $item->name . ' (' . $paramCount . ')';
        }


        $this->__controller->set(
            array(
                'types' => array(
                    'string' => 'Input Box',
                    'text_plain' => 'Textarea',
                    'select' => 'Select',
                    'html_lite' => 'WYSIWYG Lite',
                    'html' => 'WYSIWYG',
                    'boolean' => 'Checkbox',
                    'date' => 'Date Picker',
                    'datetime' => 'Date Time Picker',
                    'map' => 'Map'
                ),
                'rules' => $rules
            )
        );
    }
}
